==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--exact match--
--file: pt.po--
Fragmente entidades de texto em letras singulares
Selecione Entidades singulares</translatorcomment>
        <translation type="obsolete">Único</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dois: Vertical</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dois: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Três: Direito</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Três: Esquerda</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Três: encima del</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Três: Debajo del</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Três: Vertical</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Três: Horizontal</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatro: Igualdade</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatro: Direito</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatro: Esquerda</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espaçamento da grade &lt; Meta espaçamento da grade</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Quatro: Igualdade</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Quatro: Esquerda</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Quatro: Direito</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Único</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Três: Debajo del</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Três: Horizontal</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Três: Vertical</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Dois: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Dois: Vertical</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+320"/>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Grade
Grelha
Posicionamento na grade</translatorcomment>
        <translation>Grelha</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translatorcomment>--exact match--
--file: pt.po--
Indique o ponto de término do guia
Indique o ângulo de fim ou [Ângulo/Comprimento da corda]</translatorcomment>
        <translation>Fim</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translatorcomment>--exact match--
--file: SnapOnEntity_pt.ts--
Ponto de corte não está na entidade.
Ponto de corte não está na entidade
Ponto de divisão não está contido na entidade.</translatorcomment>
        <translation>Na entidade</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translatorcomment>--exact match--
--file: SnapPerpendicular_pt.ts--
&amp;Perpendicular
Perpendicular
(perpendicular ao traço, \&quot;escova\&quot;)</translatorcomment>
        <translation>Perpendicular</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Centro, ponto, ângulos
Centro, ponto, ângulos
Arco com Centro, Ponto, Ângulos</translatorcomment>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Meio
Meio
Salta aos pontos de meio</translatorcomment>
        <translation>Meio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translatorcomment>--exact match--
--file: pt.po--
Corte fora o segmento
Selecione o primeiro ponto da linha de intersecção</translatorcomment>
        <translation>Intersecção</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translatorcomment>--exact match--
--file: SnapReference_pt.ts--
Indique o ponto de referência
&amp;Copie com referência</translatorcomment>
        <translation>Referência</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaçamento da grade &lt; Meta espaçamento da grade</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaçamento da grade &lt; Meta espaçamento da grade</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--exact match--
--file: pt.po--
Fragmente entidades de texto em letras singulares
Selecione Entidades singulares</translatorcomment>
        <translation type="obsolete">Único</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dois: Vertical</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dois: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Três: Direita</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Três: Esquerda</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Três: Acima</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Três: Debajo del</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Três: Vertical</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Três: Horizontal</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatro: Igualdade</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatro: Direito</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Quatro: Esquerda</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espaçamento da grade &lt; Meta espaçamento da grade</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Quatro: Igual a</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Quatro: Esquerda</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Quatro: Direita</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Único</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Três: Abaixo</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Três: Horizontal</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Três: Vertical</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Dois: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Dois: Vertical</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+252"/>
        <source>Dropped data not supported</source>
        <translation>Dados inseridos não suportados</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Importing file: </source>
        <translation>Importando o arquivo: </translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Importing URL: </source>
        <translation>Importando a URL: </translation>
    </message>
    <message>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Grade
Grelha
Posicionamento na grade</translatorcomment>
        <translation type="vanished">Grade</translation>
    </message>
    <message>
        <source>End</source>
        <translatorcomment>--exact match--
--file: pt.po--
Indique o ponto de término do guia
Indique o ângulo de fim ou [Ângulo/Comprimento da corda]</translatorcomment>
        <translation type="vanished">Fim</translation>
    </message>
    <message>
        <source>On Entity</source>
        <translatorcomment>--exact match--
--file: SnapOnEntity_pt.ts--
Ponto de corte não está na entidade.
Ponto de corte não está na entidade
Ponto de divisão não está contido na entidade.</translatorcomment>
        <translation type="vanished">Na Entidade</translation>
    </message>
    <message>
        <source>Perpendicular</source>
        <translatorcomment>--exact match--
--file: SnapPerpendicular_pt.ts--
&amp;Perpendicular
Perpendicular
(perpendicular ao traço, \&quot;escova\&quot;)</translatorcomment>
        <translation type="vanished">Perpendicular</translation>
    </message>
    <message>
        <source>Tangential</source>
        <translation type="vanished">Tangencial</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Centro, ponto, ângulos
Centro, ponto, ângulos
Arco com Centro, Ponto, Ângulos</translatorcomment>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Meio
Meio
Salta aos pontos de meio</translatorcomment>
        <translation type="vanished">Meio</translation>
    </message>
    <message>
        <source>Intersection</source>
        <translatorcomment>--exact match--
--file: pt.po--
Corte fora o segmento
Selecione o primeiro ponto da linha de intersecção</translatorcomment>
        <translation type="vanished">Interseção</translation>
    </message>
    <message>
        <source>Reference</source>
        <translatorcomment>--exact match--
--file: SnapReference_pt.ts--
Indique o ponto de referência
&amp;Copie com referência</translatorcomment>
        <translation type="vanished">Referência</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaçamento da Grade &lt; Espaçamento da Metagrade</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaçamento da Grade &lt; Espaçamento da Metagrade</translation>
    </message>
</context>
</TS>
